@@ -105,12 +105,14 @@ class EquivariantAttention(nn.Module):
         dim_head = 64,
         heads = 4,
         edge_dim = 0,
-        m_dim = 4,
+        coors_hidden_dim = 16,
         neighbors = 0,
         only_sparse_neighbors = False,
         valid_neighbor_radius = float('inf'),
         init_eps = 1e-3,
-        rel_pos_emb = None
+        rel_pos_emb = None,
+        edge_mlp_mult = 2,
+        coor_attention = False
     ):
         super().__init__()
         self.scale = dim_head ** -0.5
@@ -129,10 +131,12 @@ class EquivariantAttention(nn.Module):
 
         if has_edges:
             edge_input_dim = heads + edge_dim
+            edge_hidden = edge_input_dim * edge_mlp_mult
+
             self.edge_mlp = nn.Sequential(
-                nn.Linear(edge_input_dim, m_dim * 4),
+                nn.Linear(edge_input_dim, edge_hidden),
                 nn.GELU(),
-                nn.Linear(m_dim * 4, heads)
+                nn.Linear(edge_hidden, heads)
             )
 
             self.coors_mlp = nn.Sequential(
@@ -142,9 +146,9 @@ class EquivariantAttention(nn.Module):
             )
         else:
             self.coors_mlp = nn.Sequential(
-                nn.Linear(heads, m_dim * 4),
+                nn.Linear(heads, coors_hidden_dim),
                 nn.GELU(),
-                nn.Linear(m_dim * 4, 1),
+                nn.Linear(coors_hidden_dim, 1),
                 Rearrange('... () -> ...')
             )
 
@@ -328,7 +332,7 @@ class EnTransformer(nn.Module):
         heads = 8,
         num_edge_tokens = None,
         edge_dim = 0,
-        m_dim = 16,
+        coors_hidden_dim = 16,
         neighbors = 0,
         only_sparse_neighbors = False,
         num_adj_degrees = None,
@@ -353,7 +357,7 @@ class EnTransformer(nn.Module):
         self.layers = nn.ModuleList([])
         for _ in range(depth):
             self.layers.append(nn.ModuleList([
-                Residual(PreNorm(dim, EquivariantAttention(dim = dim, dim_head = dim_head, heads = heads, m_dim = m_dim, edge_dim = (edge_dim + adj_dim),  neighbors = neighbors, only_sparse_neighbors = only_sparse_neighbors, valid_neighbor_radius = valid_neighbor_radius, init_eps = init_eps, rel_pos_emb = rel_pos_emb))),
+                Residual(PreNorm(dim, EquivariantAttention(dim = dim, dim_head = dim_head, heads = heads, coors_hidden_dim = coors_hidden_dim, edge_dim = (edge_dim + adj_dim),  neighbors = neighbors, only_sparse_neighbors = only_sparse_neighbors, valid_neighbor_radius = valid_neighbor_radius, init_eps = init_eps, rel_pos_emb = rel_pos_emb))),
                 Residual(PreNorm(dim, FeedForward(dim = dim)))
             ]))
 
